==> odata-client-msgraph-beta-0.1.26-sources.jar: odata/msgraph/client/beta/complex/OmaSettingInteger.java <==
package odata.msgraph.client.beta.complex;

import com.fasterxml.jackson.annotation.JacksonInject;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.UnmappedFields;

import java.util.Optional;


/**
 * <i>“OMA Settings Integer definition.”</i>
 */@JsonPropertyOrder({
    "@odata.type", 
    "value", 
    "isReadOnly"})
@JsonInclude(Include.NON_NULL)
public class OmaSettingInteger extends OmaSetting implements ODataType {

    @JacksonInject
    @JsonIgnore
    protected UnmappedFields unmappedFields;

    @JsonProperty("value")
    protected Integer value;

    @JsonProperty("isReadOnly")
    protected Boolean isReadOnly;

    protected OmaSettingInteger() {
        super();
    }

    @Override
    public String odataTypeName() {
        return "microsoft.graph.omaSettingInteger";
    }

    /**
     * <i>“Value.”</i>
     * 
     * @return property value
     */
    @Property(name="value")
    @JsonIgnore
    public Optional<Integer> getValue() {
        return Optional.ofNullable(value);
    }

    /**
     * Returns an immutable copy of {@code this} with just the {@code value} field
     * changed. Field description below. The field name is also added to an internal
     * map of changed fields in the returned object so that when {@code this.patch()}
     * is called (if available)on the returned object only the changed fields are
     * submitted.
     * <p>
     * <i>“Value.”</i>
     * 
     * @param value
     *            new value of {@code value} field (as defined in service metadata)
     * @return immutable copy of {@code this} with just the {@code value} field changed
     */
    public OmaSettingInteger withValue(Integer value) {
        OmaSettingInteger _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.omaSettingInteger");
        _x.value = value;
        return _x;
    }

    /**
     * <i>“By setting to true, the CSP (configuration service provider) specified in the
     * OMA-URI will perform a get, instead of set”</i>
     * 
     * @return property isReadOnly
     */
    @Property(name="isReadOnly")
    @JsonIgnore
    public Optional<Boolean> getIsReadOnly() {
        return Optional.ofNullable(isReadOnly);
    }

    /**
     * Returns an immutable copy of {@code this} with just the {@code isReadOnly} field
     * changed. Field description below. The field name is also added to an internal
     * map of changed fields in the returned object so that when {@code this.patch()}
     * is called (if available)on the returned object only the changed fields are
     * submitted.
     * <p>
     * <i>“By setting to true, the CSP (configuration service provider) specified in the
     * OMA-URI will perform a get, instead of set”</i>
     * 
     * @param isReadOnly
     *            new value of {@code isReadOnly} field (as defined in service metadata)
     * @return immutable copy of {@code this} with just the {@code isReadOnly} field changed
     */
    public OmaSettingInteger withIsReadOnly(Boolean isReadOnly) {
        OmaSettingInteger _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.omaSettingInteger");
        _x.isReadOnly = isReadOnly;
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFields();
        }
        unmappedFields.put(name, value);
    }

    @Override
    @JsonIgnore
    public UnmappedFields getUnmappedFields() {
        return unmappedFields == null ? new UnmappedFields() : unmappedFields;
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builderOmaSettingInteger() {
        return new Builder();
    }

    public static final class Builder {
        private String displayName;
        private String description;
        private String omaUri;
        private Integer value;
        private Boolean isReadOnly;
        private ChangedFields changedFields = new ChangedFields();

        Builder() {
            // prevent instantiation
        }

        public Builder displayName(String displayName) {
            this.displayName = displayName;
            this.changedFields = changedFields.add("displayName");
            return this;
        }

        public Builder description(String description) {
            this.description = description;
            this.changedFields = changedFields.add("description");
            return this;
        }

        public Builder omaUri(String omaUri) {
            this.omaUri = omaUri;
            this.changedFields = changedFields.add("omaUri");
            return this;
        }

        /**
         * <i>“Value.”</i>
         * 
         * @param value
         *            value of {@code value} property (as defined in service metadata)
         * @return {@code this} (for method chaining)
         */
        public Builder value(Integer value) {
            this.value = value;
            this.changedFields = changedFields.add("value");
            return this;
        }

        /**
         * <i>“By setting to true, the CSP (configuration service provider) specified in the
         * OMA-URI will perform a get, instead of set”</i>
         * 
         * @param isReadOnly
         *            value of {@code isReadOnly} property (as defined in service metadata)
         * @return {@code this} (for method chaining)
         */
        public Builder isReadOnly(Boolean isReadOnly) {
            this.isReadOnly = isReadOnly;
            this.changedFields = changedFields.add("isReadOnly");
            return this;
        }

        public OmaSettingInteger build() {
            OmaSettingInteger _x = new OmaSettingInteger();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFields();
            _x.odataType = "microsoft.graph.omaSettingInteger";
            _x.displayName = displayName;
            _x.description = description;
            _x.omaUri = omaUri;
            _x.value = value;
            _x.isReadOnly = isReadOnly;
            return _x;
        }
    }

    private OmaSettingInteger _copy() {
        OmaSettingInteger _x = new OmaSettingInteger();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields;
        _x.odataType = odataType;
        _x.displayName = displayName;
        _x.description = description;
        _x.omaUri = omaUri;
        _x.value = value;
        _x.isReadOnly = isReadOnly;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("OmaSettingInteger[");
        b.append("displayName=");
        b.append(this.displayName);
        b.append(", ");
        b.append("description=");
        b.append(this.description);
        b.append(", ");
        b.append("omaUri=");
        b.append(this.omaUri);
        b.append(", ");
        b.append("value=");
        b.append(this.value);
        b.append(", ");
        b.append("isReadOnly=");
        b.append(this.isReadOnly);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}

==> odata-client-msgraph-beta-0.2.2-sources.jar: odata/msgraph/client/beta/complex/OmaSettingInteger.java <==
package odata.msgraph.client.beta.complex;

import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.UnmappedFields;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.UnmappedFieldsImpl;

import java.lang.Boolean;
import java.lang.Integer;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.StringBuilder;
import java.util.Optional;


/**
 * <i>“OMA Settings Integer definition.”</i>
 */@JsonPropertyOrder({
    "@odata.type", 
    "isReadOnly", 
    "value"})
@JsonInclude(Include.NON_NULL)
public class OmaSettingInteger extends OmaSetting implements ODataType {

    @JsonProperty("isReadOnly")
    protected Boolean isReadOnly;

    @JsonProperty("value")
    protected Integer value;

    protected OmaSettingInteger() {
        super();
    }

    @Override
    public String odataTypeName() {
        return "microsoft.graph.omaSettingInteger";
    }

    /**
     * <i>“By setting to true, the CSP (configuration service provider) specified in the
     * OMA-URI will perform a get, instead of set”</i>
     * 
     * @return property isReadOnly
     */
    @Property(name="isReadOnly")
    @JsonIgnore
    public Optional<Boolean> getIsReadOnly() {
        return Optional.ofNullable(isReadOnly);
    }

    /**
     * Returns an immutable copy of {@code this} with just the {@code isReadOnly} field
     * changed. Field description below. The field name is also added to an internal
     * map of changed fields in the returned object so that when {@code this.patch()}
     * is called (if available)on the returned object only the changed fields are
     * submitted.
     * <p>
     * <i>“By setting to true, the CSP (configuration service provider) specified in the
     * OMA-URI will perform a get, instead of set”</i>
     * 
     * @param isReadOnly
     *            new value of {@code isReadOnly} field (as defined in service metadata)
     * @return immutable copy of {@code this} with just the {@code isReadOnly} field changed
     */
    public OmaSettingInteger withIsReadOnly(Boolean isReadOnly) {
        OmaSettingInteger _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.omaSettingInteger");
        _x.isReadOnly = isReadOnly;
        return _x;
    }

    /**
     * <i>“Value.”</i>
     * 
     * @return property value
     */
    @Property(name="value")
    @JsonIgnore
    public Optional<Integer> getValue() {
        return Optional.ofNullable(value);
    }

    /**
     * Returns an immutable copy of {@code this} with just the {@code value} field
     * changed. Field description below. The field name is also added to an internal
     * map of changed fields in the returned object so that when {@code this.patch()}
     * is called (if available)on the returned object only the changed fields are
     * submitted.
     * <p>
     * <i>“Value.”</i>
     * 
     * @param value
     *            new value of {@code value} field (as defined in service metadata)
     * @return immutable copy of {@code this} with just the {@code value} field changed
     */
    public OmaSettingInteger withValue(Integer value) {
        OmaSettingInteger _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.omaSettingInteger");
        _x.value = value;
        return _x;
    }

    public OmaSettingInteger withUnmappedField(String name, Object value) {
        OmaSettingInteger _x = _copy();
        _x.setUnmappedField(name, value);
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFieldsImpl();
        }
        unmappedFields.put(name, value);
    }

    @JsonAnyGetter
    private UnmappedFieldsImpl unmappedFields() {
        return unmappedFields == null ? UnmappedFieldsImpl.EMPTY : unmappedFields;
    }

    @Override
    public UnmappedFields getUnmappedFields() {
        return unmappedFields();
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builderOmaSettingInteger() {
        return new Builder();
    }

    public static final class Builder {
        private String description;
        private String displayName;
        private Boolean isEncrypted;
        private String omaUri;
        private String secretReferenceValueId;
        private Boolean isReadOnly;
        private Integer value;
        private ChangedFields changedFields = ChangedFields.EMPTY;

        Builder() {
            // prevent instantiation
        }

        public Builder description(String description) {
            this.description = description;
            this.changedFields = changedFields.add("description");
            return this;
        }

        public Builder displayName(String displayName) {
            this.displayName = displayName;
            this.changedFields = changedFields.add("displayName");
            return this;
        }

        public Builder isEncrypted(Boolean isEncrypted) {
            this.isEncrypted = isEncrypted;
            this.changedFields = changedFields.add("isEncrypted");
            return this;
        }

        public Builder omaUri(String omaUri) {
            this.omaUri = omaUri;
            this.changedFields = changedFields.add("omaUri");
            return this;
        }

        public Builder secretReferenceValueId(String secretReferenceValueId) {
            this.secretReferenceValueId = secretReferenceValueId;
            this.changedFields = changedFields.add("secretReferenceValueId");
            return this;
        }

        /**
         * <i>“By setting to true, the CSP (configuration service provider) specified in the
         * OMA-URI will perform a get, instead of set”</i>
         * 
         * @param isReadOnly
         *            value of {@code isReadOnly} property (as defined in service metadata)
         * @return {@code this} (for method chaining)
         */
        public Builder isReadOnly(Boolean isReadOnly) {
            this.isReadOnly = isReadOnly;
            this.changedFields = changedFields.add("isReadOnly");
            return this;
        }

        /**
         * <i>“Value.”</i>
         * 
         * @param value
         *            value of {@code value} property (as defined in service metadata)
         * @return {@code this} (for method chaining)
         */
        public Builder value(Integer value) {
            this.value = value;
            this.changedFields = changedFields.add("value");
            return this;
        }

        public OmaSettingInteger build() {
            OmaSettingInteger _x = new OmaSettingInteger();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFieldsImpl();
            _x.odataType = "microsoft.graph.omaSettingInteger";
            _x.description = description;
            _x.displayName = displayName;
            _x.isEncrypted = isEncrypted;
            _x.omaUri = omaUri;
            _x.secretReferenceValueId = secretReferenceValueId;
            _x.isReadOnly = isReadOnly;
            _x.value = value;
            return _x;
        }
    }

    private OmaSettingInteger _copy() {
        OmaSettingInteger _x = new OmaSettingInteger();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields.copy();
        _x.odataType = odataType;
        _x.description = description;
        _x.displayName = displayName;
        _x.isEncrypted = isEncrypted;
        _x.omaUri = omaUri;
        _x.secretReferenceValueId = secretReferenceValueId;
        _x.isReadOnly = isReadOnly;
        _x.value = value;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("OmaSettingInteger[");
        b.append("description=");
        b.append(this.description);
        b.append(", ");
        b.append("displayName=");
        b.append(this.displayName);
        b.append(", ");
        b.append("isEncrypted=");
        b.append(this.isEncrypted);
        b.append(", ");
        b.append("omaUri=");
        b.append(this.omaUri);
        b.append(", ");
        b.append("secretReferenceValueId=");
        b.append(this.secretReferenceValueId);
        b.append(", ");
        b.append("isReadOnly=");
        b.append(this.isReadOnly);
        b.append(", ");
        b.append("value=");
        b.append(this.value);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}
